@@ -26,16 +26,22 @@ void cancel_callback (GtkWidget *widget, gpointer data);
 
 static const char* const *the_items;
 
+static void
+esc_cancel (void)
+{
+	exit (-1);
+}
+
 static void okayed(GtkWidget *w, int i)
 {
-  write(2, the_items[2*i], strlen(the_items[2*i]));
-  write(2, "\n", 1);
-  exit(i);
+	write(2, the_items[2*i], strlen(the_items[2*i]));
+	write(2, "\n", 1);
+	exit(0);
 }
 
 void cancel_callback (GtkWidget *widget, gpointer data)
 {
-	gtk_exit (-2);
+	exit (1);
 }
 
 static int menu_width, tag_x, item_x;
@@ -70,15 +76,20 @@ int dialog_menu(const char *title, const char *prompt, int height, int width,
 		int menu_height, int item_no, const char *const *items)
 {
 	int i, x, y, cur_x, cur_y, box_x, box_y;
-	int key = 0, button = 0, choice = 0, scroll = 0, max_choice;
+	int key = 0, button = GTK_RESPONSE_OK, choice = 0, scroll = 0, max_choice;
 	WINDOW *dialog, *menu;
 
 	max_choice = MIN(menu_height, item_no);
 	
 	if(gnome_mode)
 	{
-		GtkWidget *w = gnome_dialog_new(title, 	
-			GNOME_STOCK_BUTTON_CANCEL, NULL);
+		GtkWidget *w  = gtk_dialog_new_with_buttons (title,
+				NULL,
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_STOCK_CANCEL,
+				GTK_RESPONSE_CANCEL,
+				NULL);
+
 		GtkWidget *hbox;
 		GtkWidget *vbox;
 		GtkWidget *but;
@@ -88,11 +99,10 @@ int dialog_menu(const char *title, const char *prompt, int height, int width,
 		
 		the_items = items;
 
-		gnome_dialog_set_close(GNOME_DIALOG(w), TRUE);
+                gtk_signal_connect (GTK_OBJECT (w), "response",
+                              GTK_SIGNAL_FUNC (esc_cancel), NULL);
+
 		gtk_window_set_title(GTK_WINDOW(w), title);
-		gnome_dialog_button_connect (GNOME_DIALOG (w), 0,
-					     GTK_SIGNAL_FUNC(cancel_callback),
-					     NULL);
 		
 		hbox = gtk_hbox_new(FALSE, 0);
 		vbox = gtk_vbox_new(FALSE, 0);
@@ -131,7 +141,7 @@ int dialog_menu(const char *title, const char *prompt, int height, int width,
 		gtk_box_pack_start(GTK_BOX(vbox), butframe, TRUE, TRUE, 0);
 		gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
 
-		gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(w)->vbox), 
+		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(w)->vbox), 
 			hbox,
 			TRUE, TRUE, GNOME_PAD);
 		gtk_window_set_position(GTK_WINDOW(w), GTK_WIN_POS_CENTER);
@@ -367,17 +377,20 @@ int dialog_menu(const char *title, const char *prompt, int height, int width,
 			return -2;
 		case M_EVENT + 'o':	/* mouse enter... */
 		case M_EVENT + 'c':	/* use the code for toggling */
-			button = (key == M_EVENT + 'o');
+			if(key == M_EVENT + 'o')
+				button = GTK_RESPONSE_CANCEL;  
+			else
+				button = GTK_RESPONSE_OK; 
 		case ' ':
 		case TAB:
 		case KEY_LEFT:
 		case KEY_RIGHT:
-			if (!button) {
-				button = 1;	/* Indicates "Cancel" button is selected */
+			if (button == GTK_RESPONSE_OK) {
+				button = GTK_RESPONSE_CANCEL;/* Indicates "Cancel" button is selected */
 				print_button(dialog, "  OK  ", y, x, FALSE);
 				print_button(dialog, "Cancel", y, x + 14, TRUE);
 			} else {
-				button = 0;	/* Indicates "OK" button is selected */
+				button = GTK_RESPONSE_OK;/* Indicates "OK" button is selected */
 				print_button(dialog, "Cancel", y, x + 14, FALSE);
 				print_button(dialog, "  OK  ", y, x, TRUE);
 			}
@@ -385,7 +398,8 @@ int dialog_menu(const char *title, const char *prompt, int height, int width,
 			break;
 		case '\n':
 			delwin(dialog);
-			return (button ? -2 : (scroll + choice));
+			if (button == GTK_RESPONSE_CANCEL) return -2;
+			return scroll+choice;
 		case ESC:
 			break;
 		}
