@@ -21,7 +21,8 @@
 
 #include <config.h>
 #include <gnome.h>
-#include "config.h"
+#include <locale.h>
+#include <errno.h>
 #include "logview.h"
 #include "logrtns.h"
 
@@ -68,7 +69,7 @@ extern GList *actions_db;
  * -------------------
  */
 
-char *
+const char *
 C_monthname[12] =
 { "January",
   "February",
@@ -83,11 +84,19 @@ C_monthname[12] =
   "November",
   "December" };
 
+/* space separated list of locales to check, must be space separated, no
+ * newlines */
+/* FIXME: This should be checked for at configure time or something to
+ * that effect */
+char *all_locales = "af_ZA ar_SA bg_BG ca_ES cs_CZ da_DK de_AT de_BE de_CH de_DE de_LU el_GR en_AU en_CA en_DK en_GB en_IE en_US es_ES et_EE eu_ES fi_FI fo_FO fr_BE fr_CA fr_CH fr_FR fr_LU ga_IE gl_ES gv_GB hr_HR hu_HU in_ID is_IS it_CH it_IT iw_IL kl_GL kw_GB lt_LT lv_LV mk_MK nl_BE nl_NL no_NO pl_PL pt_BR pt_PT ro_RO ru_RU.KOI8-R ru_RU ru_UA sk_SK sl_SI sr_YU sv_FI sv_SE th_TH tr_TR uk_UA";
+
 static int
 get_month (const char *str)
 {
-	int i;
+	int i, j;
 	static char *monthname[12] = { 0 };
+	static GHashTable *locales_monthnames = NULL;
+	static char **locales = NULL;
 
 	for (i = 0; i < 12; i++) {
 		if (g_strncasecmp (str, C_monthname[i], 3) == 0) {
@@ -117,6 +126,51 @@ get_month (const char *str)
 		}
 	}
 
+	if (locales == NULL)
+		locales = g_strsplit (all_locales, " ", 0);
+
+	if (locales_monthnames == NULL)
+		locales_monthnames = g_hash_table_new (g_str_hash, g_str_equal);
+
+	/* Try all known locales */
+	for (j = 0; locales != NULL && locales[j] != NULL; j++) {
+		for (i = 0; i < 12; i++) {
+			char *key = g_strdup_printf ("%s %d", locales[j], i);
+			char *name = g_hash_table_lookup (locales_monthnames, key);
+			if (name == NULL) {
+				char buf[256];
+				char *old_locale = g_strdup (setlocale (LC_TIME, NULL));
+				
+				if (setlocale (LC_TIME, locales[j]) == NULL) {
+					strcpy (buf, "");
+				} else {
+					GDate *date;
+
+					date = g_date_new_dmy (1, i+1, 2000 /* bogus */);
+
+					if (g_date_strftime (buf, sizeof (buf), "%b", date) <= 0) {
+						strcpy (buf, "");
+					}
+
+					if (old_locale != NULL) {
+						setlocale (LC_TIME, old_locale);
+						g_free (old_locale);
+					}
+				}
+
+				name = g_strdup (buf);
+				g_hash_table_insert (locales_monthnames, g_strdup (key), name);
+			}
+			g_free (key);
+
+			if (name != NULL &&
+			    name[0] != '\0' &&
+			    g_strcasecmp (str, name) == 0) {
+				return i;
+			}
+		}
+	}
+
 	return 12;
 }
 
@@ -240,8 +294,8 @@ isLogFile (char *filename)
    if ((fstatus.st_mode & S_IRUSR) == 0)
    {
       g_snprintf (buff, sizeof (buff),
-		  _("%s is not user readable. Probably has read-only "
-      "permission. Either run the program as root or ask the sysadmin to "
+		  _("%s is not user readable. "
+      "Either run the program as root or ask the sysadmin to "
       "change the permissions on the file."), filename);
       ShowErrMessage (buff);
       return FALSE;
@@ -252,12 +306,16 @@ isLogFile (char *filename)
    fp = fopen (filename, "r");
    if (fp == NULL)
    {
+      /* FIXME: this error message is really quite poor
+       * we should state why the open failed
+       * ie. file too large etc etc..
+       */
       g_snprintf (buff, sizeof (buff),
 		  _("%s could not be opened."), filename);
       ShowErrMessage (buff);
       return FALSE;
    }
-   fgets (buff, 255, fp);
+   fgets (buff, sizeof (buff), fp);
    fclose (fp);
    token = strtok (buff, " ");
    /* This is not a good assumption I don't think, especially
@@ -272,6 +330,13 @@ isLogFile (char *filename)
    }
    */
 
+   if (token == NULL)
+   {
+      g_snprintf (buff, sizeof (buff), _("%s not a log file."), filename);
+      ShowErrMessage (buff);
+      return FALSE;
+   }
+
    i = get_month (token);
 
    if (i == 12)
@@ -352,7 +417,8 @@ ReadPageUp (Log * lg, Page * pg)
 {
    LogLine *line;
    FILE *fp;
-   char *c, ch, buffer[R_BUF_SIZE + 1];
+   char *c, buffer[R_BUF_SIZE + 1];
+   int ch;
    int ln;
    long int old_pos;
 
@@ -423,7 +489,8 @@ ReadPageDown (Log * lg, Page * pg, gboolean exec_actions)
 {
    FILE *fp;
    LogLine *line;
-   char *c, ch, buffer[R_BUF_SIZE + 1];
+   char *c, buffer[R_BUF_SIZE + 1];
+   int ch;
    int ln, len;
 
    g_return_val_if_fail (lg != NULL, FALSE);
@@ -768,7 +835,7 @@ ReadLogStats (Log * log)
       if (IsLeapYear (curmark->year - lastyear + thisyear))
 	 curmark->time += 24 * 60 * 60;		/*  Add one day */
 
-#ifdef __NetBSD__
+#if defined(__NetBSD__) || defined(__FreeBSD__)
       curmark->time += correction - tmptm->tm_gmtoff;
 #else
       curmark->time += correction - timezone;
@@ -794,7 +861,7 @@ ReadLogStats (Log * log)
    if (IsLeapYear (thisyear))
       log->lstats.enddate += 24 * 60 * 60;	/*  Add one day */
 
-#ifdef __NetBSD__
+#if defined(__NetBSD__) || defined(__FreeBSD__)
    log->lstats.enddate += correction - tmptm->tm_gmtoff;
 #else
    log->lstats.enddate += correction - timezone;
@@ -805,7 +872,7 @@ ReadLogStats (Log * log)
    if (IsLeapYear (thisyear - lastyear))
       log->lstats.startdate += 24 * 60 * 60;	/*  Add one day */
 
-#ifdef __NetBSD__
+#if defined(__NetBSD__) || defined(__FreeBSD__)
    log->lstats.startdate += correction - tmptm->tm_gmtoff;
 #else
    log->lstats.startdate += correction - timezone;
